==> php54-owncloud-8.0.3.tgz: share/owncloud/settings/l10n/he.js <==
OC.L10N.register(
    "settings",
    {
    "Cron" : "Cron",
    "Sharing" : "שיתוף",
    "Security" : "אבטחה",
    "Log" : "יומן",
    "Authentication error" : "שגיאת הזדהות",
    "Language changed" : "שפה השתנתה",
    "Invalid request" : "בקשה לא חוקית",
    "Admins can't remove themself from the admin group" : "מנהלים לא יכולים להסיר את עצמם מקבוצת המנהלים",
    "Unable to add user to group %s" : "לא ניתן להוסיף משתמש לקבוצה %s",
    "Unable to remove user from group %s" : "לא ניתן להסיר משתמש מהקבוצה %s",
    "Couldn't update app." : "לא ניתן לעדכן את היישום.",
    "Saved" : "נשמר",
    "Email sent" : "הודעת הדוא״ל נשלחה",
    "Email saved" : "הדוא״ל נשמר",
    "All" : "הכל",
    "Please wait...." : "נא להמתין…",
    "Disable" : "בטל",
    "Enable" : "הפעלה",
    "Updating...." : "מתבצע עדכון…",
    "Error while updating app" : "אירעה שגיאה בעת עדכון היישום",
    "Updated" : "מעודכן",
    "Delete" : "מחיקה",
    "Groups" : "קבוצות",
    "undo" : "ביטול",
    "never" : "לעולם לא",
    "add group" : "הוספת קבוצה",
    "A valid username must be provided" : "יש לספק שם משתמש תקני",
    "Error creating user" : "יצירת המשתמש נכשלה",
    "A valid password must be provided" : "יש לספק ססמה תקנית",
    "__language_name__" : "עברית",
    "SSL root certificates" : "שורש אישורי אבטחת SSL ",
    "Encryption" : "הצפנה",
    "None" : "כלום",
    "Login" : "התחברות",
    "Security Warning" : "אזהרת אבטחה",
    "Setup Warning" : "שגיאת הגדרה",
    "Module 'fileinfo' missing" : "המודול „fileinfo“ חסר",
    "Please double check the <a href='%s'>installation guides</a>." : "נא לעיין שוב ב<a href='%s'>מדריכי ההתקנה</a>.",
    "Execute one task with each page loaded" : "יש להפעיל משימה אחת עם כל עמוד שנטען",
    "Allow apps to use the Share API" : "לאפשר ליישום להשתמש ב־API השיתוף",
    "Allow resharing" : "לאפשר שיתוף מחדש",
    "Enforce HTTPS" : "לאלץ HTTPS",
    "Server address" : "כתובת שרת",
    "Port" : "פורט",
    "Credentials" : "פרטי גישה",
    "Log level" : "רמת הדיווח",
    "More" : "יותר",
    "Less" : "פחות",
    "Version" : "גרסא",
    "Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." : "פותח על די <a href=\"http://ownCloud.org/contact\" target=\"_blank\">קהילתownCloud</a>, <a href=\"https://github.com/owncloud\" target=\"_blank\">קוד המקור</a> מוגן ברישיון <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
    "More apps" : "יישומים נוספים",
    "by" : "על ידי",
    "User Documentation" : "תיעוד משתמש",
    "Administrator Documentation" : "תיעוד מנהלים",
    "Online Documentation" : "תיעוד מקוון",
    "Forum" : "פורום",
    "Bugtracker" : "עוקב תקלות",
    "Commercial Support" : "תמיכה בתשלום",
    "Get the apps to sync your files" : "השג את האפליקציות על מנת לסנכרן את הקבצים שלך",
    "Show First Run Wizard again" : "הצגת אשף ההפעלה הראשונית שוב",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "השתמשת ב־<strong>%s</strong> מתוך <strong>%s</strong> הזמינים לך",
    "Password" : "סיסמא",
    "Your password was changed" : "הססמה שלך הוחלפה",
    "Unable to change your password" : "לא ניתן לשנות את הססמה שלך",
    "Current password" : "ססמה נוכחית",
    "New password" : "ססמה חדשה",
    "Change password" : "שינוי ססמה",
    "Email" : "דואר אלקטרוני",
    "Your email address" : "כתובת הדוא״ל שלך",
    "Profile picture" : "תמונת פרופיל",
    "Cancel" : "ביטול",
    "Language" : "פה",
    "Help translate" : "עזרה בתרגום",
    "Import Root Certificate" : "ייבוא אישור אבטחת שורש",
    "Username" : "שם משתמש",
    "Create" : "יצירה",
    "Admin Recovery Password" : "ססמת השחזור של המנהל",
    "Group" : "קבוצה",
    "Default Quota" : "מכסת בררת המחדל",
    "Unlimited" : "ללא הגבלה",
    "Other" : "אחר",
    "Quota" : "מכסה",
    "set new password" : "הגדרת ססמה חדשה",
    "Default" : "בררת מחדל"
},
"nplurals=2; plural=(n != 1);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/settings/l10n/he.js <==
OC.L10N.register(
    "settings",
    {
    "Sharing" : "שיתוף",
    "External Storage" : "אחסון חיצוני",
    "Cron" : "Cron",
    "Log" : "יומן",
    "Authentication error" : "שגיאת הזדהות",
    "Language changed" : "שפה השתנתה",
    "Invalid request" : "בקשה לא חוקית",
    "Admins can't remove themself from the admin group" : "מנהלים לא יכולים להסיר את עצמם מקבוצת המנהלים",
    "Unable to add user to group %s" : "לא ניתן להוסיף משתמש לקבוצה %s",
    "Unable to remove user from group %s" : "לא ניתן להסיר משתמש מהקבוצה %s",
    "Couldn't update app." : "לא ניתן לעדכן את היישום.",
    "Saved" : "נשמר",
    "Email sent" : "הודעת הדוא״ל נשלחה",
    "Email saved" : "הדוא״ל נשמר",
    "All" : "הכל",
    "Please wait...." : "נא להמתין…",
    "Disable" : "בטל",
    "Enable" : "הפעלה",
    "Updating...." : "מתבצע עדכון…",
    "Error while updating app" : "אירעה שגיאה בעת עדכון היישום",
    "Updated" : "מעודכן",
    "Delete" : "מחיקה",
    "Groups" : "קבוצות",
    "undo" : "ביטול",
    "never" : "לעולם לא",
    "add group" : "הוספת קבוצה",
    "A valid username must be provided" : "יש לספק שם משתמש תקני",
    "Error creating user" : "יצירת המשתמש נכשלה",
    "A valid password must be provided" : "יש לספק ססמה תקנית",
    "__language_name__" : "עברית",
    "SSL root certificates" : "שורש אישורי אבטחת SSL ",
    "None" : "כלום",
    "Login" : "התחברות",
    "Allow apps to use the Share API" : "לאפשר ליישום להשתמש ב־API השיתוף",
    "Allow resharing" : "לאפשר שיתוף מחדש",
    "Execute one task with each page loaded" : "יש להפעיל משימה אחת עם כל עמוד שנטען",
    "Encryption" : "הצפנה",
    "Server address" : "כתובת שרת",
    "Port" : "פורט",
    "Credentials" : "פרטי גישה",
    "Log level" : "רמת הדיווח",
    "More" : "יותר",
    "Less" : "פחות",
    "Version" : "גרסא",
    "by" : "על ידי",
    "User Documentation" : "תיעוד משתמש",
    "Forum" : "פורום",
    "Get the apps to sync your files" : "השג את האפליקציות על מנת לסנכרן את הקבצים שלך",
    "Show First Run Wizard again" : "הצגת אשף ההפעלה הראשונית שוב",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "השתמשת ב־<strong>%s</strong> מתוך <strong>%s</strong> הזמינים לך",
    "Password" : "סיסמא",
    "Unable to change your password" : "לא ניתן לשנות את הססמה שלך",
    "Current password" : "ססמה נוכחית",
    "New password" : "ססמה חדשה",
    "Change password" : "שינוי ססמה",
    "Email" : "דואר אלקטרוני",
    "Your email address" : "כתובת הדוא״ל שלך",
    "Profile picture" : "תמונת פרופיל",
    "Cancel" : "ביטול",
    "Language" : "פה",
    "Help translate" : "עזרה בתרגום",
    "Username" : "שם משתמש",
    "Create" : "יצירה",
    "Admin Recovery Password" : "ססמת השחזור של המנהל",
    "Group" : "קבוצה",
    "Default Quota" : "מכסת בררת המחדל",
    "Unlimited" : "ללא הגבלה",
    "Other" : "אחר",
    "Quota" : "מכסה",
    "set new password" : "הגדרת ססמה חדשה",
    "Default" : "בררת מחדל"
},
"nplurals=2; plural=(n != 1);");
